@@ -6,8 +6,8 @@ function(FILEPATH,MEASURES,MAXSAMPLESIZE,SMALL,MEDIUM,LARGE,SUMMARYFILENAME,TIME
 	{
 		TIMEPOINTANALYSED<-TIMEPOINTS[n]
 
-		ATESTSUMMARYFILE <- paste(SUMMARYFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
-		GRAPHOUTPUTFILE <- paste("ATestMaxes_",TIMEPOINTANALYSED,".pdf",sep="")
+		ATESTSUMMARYFILE <- paste(SUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")
+		GRAPHOUTPUTFILE <- paste("ATestMaxes_",TIMEPOINTANALYSED,sep="")
 
 		aa_graphSampleSizeSummary(FILEPATH,MEASURES,MAXSAMPLESIZE,SMALL,MEDIUM,LARGE,ATESTSUMMARYFILE,GRAPHOUTPUTFILE,TIMEPOINTANALYSED,TIMEPOINTSCALE)
 	}
