@@ -1,5 +1,6 @@
 efast_generate_medians_for_all_parameter_subsets <-
-function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,NUMRUNSPERSAMPLE,MEASURES,OUTPUTCOLSTART,OUTPUTCOLEND,RESULTFILENAME,ALTERNATIVEFILENAME,MEDIANSFILENAME)
+function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,NUMRUNSPERSAMPLE,MEASURES,RESULTFILEFORMAT,RESULTFILENAME,ALTERNATIVEFILENAME,OUTPUTCOLSTART,
+		OUTPUTCOLEND,MEDIANSFILEFORMAT,MEDIANSFILENAME)
 {
 	if(file.exists(FILEPATH))
 	{
@@ -15,11 +16,13 @@ function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,NUMRUNSPERSAMPLE,MEASURES,OUTP
 				for(j in 1:NUMSAMPLES)
 				{
 					SAMPLEFILEDIR<-paste(FILEPATH,"/",CURVE,"/",PARAM,"/",j,"/",sep="")
+					
+					MEDIANRESULTSPATH = paste(SAMPLEFILEDIR,"/",MEDIANSFILENAME,sep="")
 	
-					if(!file.exists(paste(SAMPLEFILEDIR,MEDIANSFILENAME,sep="")))
+					if(!file.exists(paste(MEDIANRESULTSPATH,".csv",sep="")) | !file.exists(paste(MEDIANRESULTSPATH,".xml",sep="")))
 					{
-						getMediansSubset(SAMPLEFILEDIR,NUMRUNSPERSAMPLE,OUTPUTCOLSTART,OUTPUTCOLEND,MEASURES,RESULTFILENAME,ALTERNATIVEFILENAME,MEDIANSFILENAME)
-						
+						getMediansSubset(SAMPLEFILEDIR,NUMRUNSPERSAMPLE,MEASURES,RESULTFILEFORMAT,RESULTFILENAME,ALTERNATIVEFILENAME,
+								OUTPUTCOLSTART,OUTPUTCOLEND,MEDIANSFILEFORMAT,MEDIANSFILENAME)
 					}
 				}
 		
