@@ -1,5 +1,5 @@
 efast_get_overall_medians <-
-function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,MEASURES,MEDIANSFILENAME,CURVERESULTSFILENAME)
+function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,MEASURES,MEDIANSFILEFORMAT,MEDIANSFILENAME,CURVERESULTSFILENAME)
 {
 	if(file.exists(FILEPATH))
 	{
@@ -16,21 +16,36 @@ function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,MEASURES,MEDIANSFILENAME,CURVE
 			for(SAMPLE in 1:NUMSAMPLES)
 			{
 				ALLRESULTSROW<-NULL
+				
 				for(PARAM in 1:length(PARAMETERS))
 				{
 					# READ IN THE MEDIANS FILE FOR THIS PARAMETER SET
 					MEDIANSFILEPATH<-paste(FILEPATH,"/",CURVE,"/",PARAM,"/",SAMPLE,sep="")
-
-					if(file.exists(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,sep="")))
+					
+					if(file.exists(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,".csv",sep="")) | 
+							file.exists(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,".xml",sep="")))
 					{
-						ALLMEDIANS<-read.csv(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,sep=""),header=TRUE)
+						if(MEDIANSFILEFORMAT=="csv")
+						{
+							MODELRESULT<-read.csv(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,".csv",sep=""),header=TRUE)
+						}
+						else if(MEDIANSFILEFORMAT=="xml")
+						{
+							# XML Median Set
+							MODELRESULT<-xmlToDataFrame(paste(MEDIANSFILEPATH,"/",MEDIANSFILENAME,".xml",sep=""))
+						}
 		
 						# FOR THIS PARAMETER SET, GENERATE THE OVERALL MEDIANS FOR EACH OF MEASURE
 						MEDIANSFORALLMEASURES<-NULL
+						
 						for(l in 1:length(MEASURES))
 						{
-							MEASUREMEDIAN <- median(ALLMEDIANS[MEASURES[l]][,1],na.rm=TRUE)
-							MEDIANSFORALLMEASURES<-cbind(MEDIANSFORALLMEASURES,MEASUREMEDIAN)
+							MEASURE_RESULT<-as.matrix(MODELRESULT[MEASURES[l]])
+							MEASUREMEDIAN<-median(as.numeric(MEASURE_RESULT),na.rm=TRUE)
+							MEDIANSFORALLMEASURES<-cbind(MEDIANSFORALLMEASURES,MEASUREMEDIAN[[1]])
+							
+							#MEASUREMEDIAN <- median(ALLMEDIANS[MEASURES[l]][,1],na.rm=TRUE)
+							#MEDIANSFORALLMEASURES<-cbind(MEDIANSFORALLMEASURES,MEASUREMEDIAN)
 						}
 		
 						# APPEND THESE TO THE ALL RESULTS NEW ROW
@@ -42,12 +57,16 @@ function(FILEPATH,NUMCURVES,PARAMETERS,NUMSAMPLES,MEASURES,MEDIANSFILENAME,CURVE
 					}
 				}
 				
-				ALLRESULTS<-rbind(ALLRESULTS,ALLRESULTSROW)
+				#print(ALLRESULTSROW)
+				if(!is.null(ALLRESULTSROW))
+				{
+					ALLRESULTS<-rbind(ALLRESULTS,ALLRESULTSROW)
+				}
 	
 			}
 	
 			# NOW WRITE THE RESULTS FOR THIS CURVE TO A FILE
-			ALLRESULTSFILE = paste(FILEPATH,CURVE,"/",CURVERESULTSFILENAME,sep="")
+			ALLRESULTSFILE = paste(FILEPATH,"/",CURVE,"/",CURVERESULTSFILENAME,".csv",sep="")
 	
 			# GENERATE THE COLHEADERS FOR PRESENTATION SAKE
 			COLHEADERS<-NULL
