@@ -5,8 +5,8 @@ function(FILEPATH,PARAMETERS,MEASURES,LHCSUMMARYFILENAME,CORCOEFFSOUTPUTFILE,TIM
 	{
 		TIMEPOINTANALYSED<-TIMEPOINTS[n]
 
-		LHCRESULTFILE<-paste(LHCSUMMARYFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
-		CORCOEFFSOUTPUTFILEFULL<-paste(CORCOEFFSOUTPUTFILE,"_",TIMEPOINTANALYSED,".csv",sep="")
+		LHCRESULTFILE<-paste(LHCSUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")
+		CORCOEFFSOUTPUTFILEFULL<-paste(CORCOEFFSOUTPUTFILE,"_",TIMEPOINTANALYSED,sep="")
 
 		lhc_generatePRCoEffs(FILEPATH,PARAMETERS,MEASURES,LHCRESULTFILE,CORCOEFFSOUTPUTFILEFULL)
 	}
