@@ -5,8 +5,9 @@ function(FILEPATH,PARAMETERS,PMIN,PMAX,PINC,ATESTRESULTSFILENAME,MEASURES,ATESTS
 	for(n in 1:length(TIMEPOINTS))
 	{
 		TIMEPOINTANALYSED<-TIMEPOINTS[n]
+		print(paste("Time Point Analysed: ",TIMEPOINTANALYSED,sep=""))
 
-		ATESTSFILENAME <- paste(ATESTRESULTSFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
+		ATESTSFILENAME <- paste(ATESTRESULTSFILENAME,"_",TIMEPOINTANALYSED,sep="")
 		
 		oat_graphATestsForSampleSize(FILEPATH,PARAMETERS,PMIN,PMAX,PINC,MEASURES,ATESTSIGLEVEL,ATESTSFILENAME,TIMEPOINTANALYSED,TIMEPOINTSCALE)
 	}
