@@ -1,6 +1,5 @@
 pcor.rec <-
-function(x,y,z,method="p",na.rm=TRUE){
-	# 
+function(x,y,z,corMethod="p",na.rm=TRUE){
 
 	x <- c(x)
 	y <- c(y)
@@ -19,13 +18,13 @@ function(x,y,z,method="p",na.rm=TRUE){
 	# recursive formula
 	if(dim(z)[2] == 1){
 		tdata <- na.omit(data.frame(data[,1],data[,2]))
-		rxy <- cor(tdata[,1],tdata[,2],method)
+		rxy <- cor(tdata[,1],tdata[,2],corMethod)
 
 		tdata <- na.omit(data.frame(data[,1],data[,-c(1,2)]))
-		rxz <- cor(tdata[,1],tdata[,2],method)
+		rxz <- cor(tdata[,1],tdata[,2],corMethod)
 
 		tdata <- na.omit(data.frame(data[,2],data[,-c(1,2)]))
-		ryz <- cor(tdata[,1],tdata[,2],method)
+		ryz <- cor(tdata[,1],tdata[,2],corMethod)
 
 		rxy.z <- (rxy - rxz*ryz)/( sqrt(1-rxz^2)*sqrt(1-ryz^2) )
 		
@@ -36,9 +35,9 @@ function(x,y,z,method="p",na.rm=TRUE){
 		z0 <- c(data[,3])
 		zc <- as.data.frame(data[,-c(1,2,3)])
 
-		rxy.zc <- pcor.rec(x,y,zc,method=method,na.rm=na.rm)
-		rxz0.zc <- pcor.rec(x,z0,zc,method=method,na.rm=na.rm)
-		ryz0.zc <- pcor.rec(y,z0,zc,method=method,na.rm=na.rm)
+		rxy.zc <- pcor.rec(x,y,zc,corMethod=corMethod,na.rm=na.rm)
+		rxz0.zc <- pcor.rec(x,z0,zc,corMethod=corMethod,na.rm=na.rm)
+		ryz0.zc <- pcor.rec(y,z0,zc,corMethod=corMethod,na.rm=na.rm)
 		
 		rxy.z <- (rxy.zc - rxz0.zc*ryz0.zc)/( sqrt(1-rxz0.zc^2)*sqrt(1-ryz0.zc^2) )
 		return(rxy.z)
